@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2019 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-
-use strict;
+# This code is part of distribution Mail-Box.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Box::Locker;
 use vars '$VERSION';
-$VERSION = '3.004';
+$VERSION = '3.006';
 
 use base 'Mail::Reporter';
 
+use strict;
+use warnings;
+
 use Carp;
 use Scalar::Util 'weaken';
 use Devel::GlobalDestruction 'in_global_destruction';
