@@ -1,15 +1,19 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2019 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution Mail-Box.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Box::Maildir;
 use vars '$VERSION';
-$VERSION = '3.004';
+$VERSION = '3.006';
 
 use base 'Mail::Box::Dir';
 
 use strict;
+use warnings;
 use filetest 'access';
 
 use Mail::Box::Maildir::Message;
@@ -236,7 +240,7 @@ sub readMessageFilenames
     # timestamp has the same length.
 
     my %unified;
-    m/^(\d+)/ and $unified{ ('0' x (9-length($1))).$_ } = $_
+    m/^(\d+)/ and $unified{ ('0' x (10-length($1))).$_ } = $_
         for @files;
 
     map "$dirname/$unified{$_}",
