@@ -1,16 +1,20 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2019 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
-use strict;
-use warnings;
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution Mail-Box.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Body::Delayed;
 use vars '$VERSION';
-$VERSION = '2.115';
+$VERSION = '3.006';
 
 use base 'Mail::Reporter';
 
+use strict;
+use warnings;
+
 use Object::Realize::Later
     becomes          => 'Mail::Message::Body',
     realize          => 'load',
@@ -53,28 +57,12 @@ sub modified(;$)
     shift->forceRealize(shift);
 }
 
-#------------------------------------------
-
-
-sub isModified() { 0 }
-
-#------------------------------------------
-
 
+sub isModified()  {0}
 sub isDelayed()   {1}
-
-#------------------------------------------
-
-
 sub isMultipart() {shift->message->head->isMultipart}
-
-#------------------------------------------
-
-
 sub guessSize()   {shift->{MMBD_size}}
 
-#------------------------------------------
-
 
 sub nrLines()
 {   my ($self) = @_;
@@ -83,11 +71,9 @@ sub nrLines()
     : $_[0]->forceRealize->nrLines;
 }
 
-#------------------------------------------
-
 sub string_unless_carp()
 {   my $self = shift;
-    return $self->load->string unless (caller)[0] eq 'Carp';
+    return $self->load->string if (caller)[0] ne 'Carp';
 
     (my $class = ref $self) =~ s/^Mail::Message/MM/g;
     "$class object";
@@ -106,8 +92,6 @@ sub read($$;$@)
     $self;
 }
 
-#------------------------------------------
-
 
 sub fileLocation(;@) {
    my $self = shift;
@@ -115,8 +99,6 @@ sub fileLocation(;@) {
    @$self{ qw/MMBD_begin MMBD_end/ } = @_;
 }
 
-#------------------------------------------
-
 
 sub moveLocation($)
 {   my ($self, $dist) = @_;
@@ -125,8 +107,6 @@ sub moveLocation($)
     $self;
 }
 
-#------------------------------------------
-
 
 sub load() {$_[0] = $_[0]->message->loadBody}
 
