@@ -1,15 +1,20 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2019 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
-use strict;
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution Mail-Box.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Head::Delayed;
 use vars '$VERSION';
-$VERSION = '2.117';
+$VERSION = '3.006';
 
 use base 'Mail::Message::Head';
 
+use strict;
+use warnings;
+
 use Object::Realize::Later
     becomes          => 'Mail::Message::Head::Complete',
     realize          => 'load',
